

# Alignments

Word alignments for Bibles, including both automatic alignments and manually corrected alignments

Copyright (c) 2023 by Clear Bible, Inc.

All data is licensed under a
[Creative Commons Attribution 4.0 International License][cc-by].


[cc-by]: http://creativecommons.org/licenses/by/4.0/
[cc-by-image]: https://i.creativecommons.org/l/by/4.0/88x31.png
[cc-by-shield]: https://img.shields.io/badge/License-CC%20BY%204.0-lightgrey.svg
[![CC BY 4.0][cc-by-image]][cc-by]

  
All code is shared under a MIT License.

## Python Quick Start

To run this code:

- ensure [Poetry](https://python-poetry.org/) is installed
- `poetry add`

## Contributing Alignments

We're interested in collecting alignments that are useful for
the Bible translation community, especially those based on
openly-licensed texts. If you have alignments to contribute, see
[Contributing](docs/contributing.md). 
